@@ -761,6 +761,9 @@ def filled_paths_in_ids(ids, ds, path=None, paths=None, requested_paths=None,
 
     # traverse
     for kid in keys:
+        if kid == 'occurrence' and path[-1] == 'ids_properties':
+            continue
+
         propagate_path = copy.copy(path)
         propagate_path.append(kid)
 
@@ -782,8 +785,9 @@ def filled_paths_in_ids(ids, ds, path=None, paths=None, requested_paths=None,
                                                     propagate_requested_paths, assume_uniform_array_structures)
         except Exception:
             # check if the issue was that we were trying to load something that was added to the _extra_structures
-            if o2i(l2u(propagate_path)) in _extra_structures[propagate_path[0]]:
-                # printe('`%s` does not exist in the IMAS data dictionary. Consider opening a JIRA issue asking for its addition: https://jira.iter.org' % l2i(path + [kid]))
+            if o2i(l2u(propagate_path)) in _extra_structures.get(propagate_path[0], {}):
+                # printe('`%s` does not exist in the IMAS data dictionary.
+                # Consider opening a JIRA issue asking for its addition: https://jira.iter.org' % l2i(path + [kid]))
                 continue
             printe('Error querying IMAS database for `%s` Possible IMAS version mismatch?' % l2i(path + [kid]))
             continue
